function h = scatter_kde(x, y, varargin)
% Scatter plot where each point is colored by the spatial density of nearby
% points. The function use the kernel smoothing function to compute the
% probability density estimate (PDE) for each point. It uses the PDE has
% color for each point.
%
% Input
%     x <Nx1 double> position of markers on X axis
%     y <Nx1 double> posiiton of markers on Y axis
%     varargin can be used to send a set of instructions to the scatter function
%           Supports the MarkerSize parameter
%           Does not support the MarkerColor parameter
%
% Output:
%     h returns handles to the scatter objects created
%
% Example
%     % Generate data
%     x = normrnd(10,1,1000,1);
%     y = x*3 + normrnd(10,1,1000,1);
%     % Plot data using probability density estimate as function
%     figure(1); 
%     scatter_kde(x, y, 'filled', 'MarkerSize', 100);
%     % Add Color bar
%     cb = colorbar();
%     cb.Label.String = 'Probability density estimate';
%
% author: Nils Haentjens
% created: Jan 15, 2018

table{1}= importfile('Specimen_001_B1_B01_007.fcs_file_internal_comp_no debris_water.txt');
table{2}= importfile('Specimen_001_B2_B02_008.fcs_file_internal_comp_no debris_PSSA_only.txt');
table{3}= importfile('Specimen_001_B3_B03_009.fcs_file_internal_comp_no debris_expCADGE_+dNTPs.txt');
table{4}= importfile('Specimen_001_B4_B04_010.fcs_file_internal_comp_no debris_expCADGE_-dNTPs.txt');
table{5}= importfile('Specimen_001_B5_B05_011.fcs_file_internal_comp_no debris_purCADGE_+dNTPs.txt');
table{6}= importfile('Specimen_001_B6_B06_012.fcs_file_internal_comp_no debris_purCADGE_-dNTPs.txt'); 

samples = ["water", "PSSA only", "expCADGE +dNTPs", "expCADGE -dNTPs", "purCADGE +dNTPs", "purCADGE -dNTPs"]

set(groot,{'DefaultAxesXColor','DefaultAxesYColor','DefaultAxesZColor','DefaultAxesLineWidth'},{'k','k','k',1})
x = 1:100:10000000;
y = (x).^2;

for c = 1:6;

% Use Kernel smoothing function to get the probability density estimate (c)
m = ksdensity([table{c}.SSCA,table{c}.PETexasRedA], [table{c}.SSCA,table{c}.PETexasRedA]);

if nargin > 2
  % Set Marker Size
  i = find(strcmp(varargin, 'MarkerSize'),1);
  if ~isempty(i); MarkerSize = varargin{i+1}; varargin(i:i+1) = [];
  else MarkerSize = []; end
  
  % Plot scatter plot
  f(c) = figure;
  box on
  set(gca,'FontSize',14);
  h = get(gca, 'title');
  set(h, 'FontSize',14)

  h = scatter(table{c}.SSCA, table{c}.PETexasRedA, MarkerSize, m, varargin{:});
  set(gca,'xscale','log')
  set(gca,'yscale','log')
  xlim([10 10^5])
  ylim([10^0 10^6])

  legend(samples(c),'Location','NW','FontSize',12)
  xlabel('SSC-A (A.U)')
  ylabel('LactC2-mCherry intensity (A.U)')
  
  legend boxoff
  set(gca,'FontSize',14);
  h = get(gca, 'title');
  set(h, 'FontSize',14)

else
    
  f(c) = figure;
  box on
  set(gca,'FontSize',14);
  h = get(gca, 'title');
  set(h, 'FontSize',14)

  
  h = scatter(table{c}.SSCA, table{c}.PETexasRedA, [], m);
  set(gca,'xscale','log')
  set(gca,'yscale','log')
  xlim([10 10^5])
  ylim([10^0 10^6])
  
  legend(samples(c),'Location','NW','FontSize',12)  
  xlabel('SSC-A')
  ylabel('LactC2-mCherry intensity (A.U)')
  
  legend boxoff
  set(gca,'FontSize',14);
  h = get(gca, 'title');
  set(h, 'FontSize',14)

end

end

end